@@ -16,10 +16,18 @@ knitr::kable(rstan::summary(samp, par = 'pg')$summary, digits = 3)
 ## ---- fig.width = 6, fig.height = 6, fig.cap = "Prob(Response | D) in subgroup 3"----
 library(ggplot2)
 library(rstan)
-ggplot(data.frame(ProbResponse = extract(samp, 'p[3]')[[1]]),
-       aes(x = ProbResponse)) + geom_density() + ggtitle('Prob(Response | D) in Sub-group 3')
+library(dplyr)
+
+as.data.frame(samp, 'p[3]') %>% 
+  mutate(ProbResponse = `p[3]`) %>% 
+  ggplot(aes(x = ProbResponse)) + 
+  geom_density() + 
+  ggtitle('Prob(Response | D) in Sub-group 3')
 
 ## ---- fig.width = 6, fig.height = 6, fig.cap = "Prob(Response | D) in subgroup 4"----
-ggplot(data.frame(ProbResponse = extract(samp, 'p[4]')[[1]]),
-       aes(x = ProbResponse)) + geom_density() + ggtitle('Prob(Response | D) in Sub-group 4')
+as.data.frame(samp, 'p[4]') %>% 
+  mutate(ProbResponse = `p[4]`) %>% 
+  ggplot(aes(x = ProbResponse)) + 
+  geom_density() + 
+  ggtitle('Prob(Response | D) in Sub-group 4')
 
